@@ -20,11 +20,14 @@ class CAISO(ISOBase):
     iso_id = "caiso"
     default_timezone = "US/Pacific"
 
-    DAY_AHEAD_HOURLY = Markets.DAY_AHEAD_HOURLY  # PRC_LMP
-    REAL_TIME_15_MIN = Markets.REAL_TIME_15_MIN  # PRC_RTPD_LMP
-    REAL_TIME_HOURLY = Markets.REAL_TIME_HOURLY  # PRC_HASP_LMP
+    # Markets PRC_RTPD_LMP, PRC_HASP_LMP, PRC_LMP
+    markets = [
+        Markets.REAL_TIME_15_MIN,
+        Markets.REAL_TIME_HOURLY,
+        Markets.DAY_AHEAD_HOURLY,
+    ]
 
-    trading_hubs_nodes = [
+    trading_hub_locations = [
         "TH_NP15_GEN-APND",
         "TH_SP15_GEN-APND",
         "TH_ZP26_GEN-APND",
@@ -159,26 +162,36 @@ class CAISO(ISOBase):
         )
         return df
 
-    def get_latest_lmp(self, market: str, nodes: list):
-        return self._latest_lmp_from_today(market, nodes, node_column="Node")
+    def get_latest_lmp(self, market: str, locations: list = None):
+        return self._latest_lmp_from_today(market, locations)
 
-    def get_lmp_today(self, market: str, nodes: list):
+    def get_lmp_today(self, market: str, locations: list = None):
         "Get lmp for today in 5 minute intervals"
-        return self._today_from_historical(self.get_historical_lmp, market, nodes)
+        return self._today_from_historical(self.get_historical_lmp, market, locations)
 
-    def get_lmp_yesterday(self, market: str, nodes: list):
+    def get_lmp_yesterday(self, market: str, locations: list = None):
         "Get lmp for yesterday in 5 minute intervals"
-        return self._yesterday_from_historical(self.get_historical_lmp, market, nodes)
+        return self._yesterday_from_historical(
+            self.get_historical_lmp,
+            market,
+            locations,
+        )
 
-    def get_historical_lmp(self, date, market: str, nodes: list, sleep: int = 5):
-        """Get day ahead LMP pricing starting at supplied date for a list of nodes.
+    def get_historical_lmp(
+        self,
+        date,
+        market: str,
+        locations: list = None,
+        sleep: int = 5,
+    ):
+        """Get day ahead LMP pricing starting at supplied date for a list of locations.
 
         Arguments:
             date: date to return data
 
             market: market to return from. supports:
 
-            nodes (list): list of nodes to get data from. If no nodes are provided, defaults to NP15, SP15, and ZP26, which are the trading hub nodes. For a list of nodes, call CAISO.get_pnodes()
+            locations (list): list of locations to get data from. If no locations are provided, defaults to NP15, SP15, and ZP26, which are the trading hub locations. For a list of locations, call CAISO.get_pnodes()
 
             sleep (int): number of seconds to sleep before returning to avoid hitting rate limit in regular usage. Defaults to 5 seconds.
 
@@ -186,36 +199,38 @@ class CAISO(ISOBase):
             dataframe of pricing data
         """
 
-        if nodes is None:
-            nodes = self.trading_hubs_nodes
+        if locations is None:
+            locations = self.trading_hub_locations
 
         # todo make sure defaults to local timezone
         start = isodata.utils._handle_date(date, tz=self.default_timezone)
 
-        nodes_str = ",".join(nodes)
-
         start = start.tz_convert("UTC")
         end = start + pd.DateOffset(1)
 
         start = start.strftime("%Y%m%dT%H:%M-0000")
         end = end.strftime("%Y%m%dT%H:%M-0000")
 
-        if market == self.DAY_AHEAD_HOURLY:
+        market = Markets(market)
+        if market == Markets.DAY_AHEAD_HOURLY:
             query_name = "PRC_LMP"
             market_run_id = "DAM"
             version = 12
             PRICE_COL = "MW"
-        elif market == self.REAL_TIME_15_MIN:
+        elif market == Markets.REAL_TIME_15_MIN:
             query_name = "PRC_RTPD_LMP"
             market_run_id = "RTPD"
             version = 3
             PRICE_COL = "PRC"
-        elif market == self.REAL_TIME_HOURLY:
+        elif market == Markets.REAL_TIME_HOURLY:
             query_name = "PRC_HASP_LMP"
             market_run_id = "HASP"
             version = 3
             PRICE_COL = "MW"
+        else:
+            raise RuntimeError("LMP Market is not supported")
 
+        nodes_str = ",".join(locations)
         url = f"http://oasis.caiso.com/oasisapi/SingleZip?resultformat=6&queryname={query_name}&version={version}&startdatetime={start}&enddatetime={end}&market_run_id={market_run_id}&node={nodes_str}"
 
         retry_num = 0
@@ -252,7 +267,7 @@ class CAISO(ISOBase):
         df = df.reset_index().rename(
             columns={
                 "INTERVALSTARTTIME_GMT": "Time",
-                "NODE": "Node",
+                "NODE": "Location",
                 "LMP": "LMP",
                 "MCE": "Energy",
                 "MCC": "Congestion",
@@ -264,11 +279,28 @@ class CAISO(ISOBase):
             df["Time"],
         ).dt.tz_convert(self.default_timezone)
 
-        df["Market"] = market
+        df["Market"] = market.value
+        df["Location Type"] = None
 
-        df = df[["Time", "Market", "Node", "LMP", "Energy", "Congestion", "Loss"]]
+        df.loc[
+            df["Location"].isin(self.trading_hub_locations),
+            "Location Type",
+        ] = "Trading Hub"
 
-        data = utils.filter_lmp_nodes(df, nodes)
+        df = df[
+            [
+                "Time",
+                "Market",
+                "Location",
+                "Location Type",
+                "LMP",
+                "Energy",
+                "Congestion",
+                "Loss",
+            ]
+        ]
+
+        data = utils.filter_lmp_locations(df, locations)
 
         time.sleep(sleep)
 
