@@ -1,7 +1,9 @@
 from bdb import set_trace
-from .base import ISOBase, FuelMix, GridStatus
+
 import pandas as pd
 
+from isodata.base import FuelMix, GridStatus, ISOBase
+
 
 class Ercot(ISOBase):
     name = "Electric Reliability Council of Texas"
@@ -13,8 +15,11 @@ class Ercot(ISOBase):
     def get_latest_status(self):
         r = self._get_json(self.BASE + "/daily-prc.json")
 
-        time = pd.to_datetime(r["current_condition"]["datetime"], unit="s").tz_localize(
-            "UTC").tz_convert(self.default_timezone)
+        time = (
+            pd.to_datetime(r["current_condition"]["datetime"], unit="s")
+            .tz_localize("UTC")
+            .tz_convert(self.default_timezone)
+        )
         status = r["current_condition"]["state"]
         reserves = float(r["current_condition"]["prc_value"].replace(",", ""))
         return GridStatus(time=time, status=status, reserves=reserves, iso=self.name)
@@ -23,10 +28,7 @@ class Ercot(ISOBase):
         df = self.get_fuel_mix_today()
         currentHour = df.iloc[-1]
 
-        mix_dict = {
-            "Wind": currentHour["Wind"],
-            "Solar": currentHour["Solar"]
-        }
+        mix_dict = {"Wind": currentHour["Wind"], "Solar": currentHour["Solar"]}
 
         return FuelMix(time=currentHour["Time"], mix=mix_dict, iso=self.name)
 
@@ -39,20 +41,16 @@ class Ercot(ISOBase):
         r = self._get_json(url)
 
         # rows with nulls are forecasts
-        df = pd.DataFrame(r['currentDay']["data"])
+        df = pd.DataFrame(r["currentDay"]["data"])
         df = df.dropna(subset=["actualSolar"])
 
-        df = self._handle_data(
-            df, {"actualSolar": "Solar", "actualWind": "Wind"})
+        df = self._handle_data(df, {"actualSolar": "Solar", "actualWind": "Wind"})
         return df
 
     def get_latest_demand(self):
-        d = self._get_demand('currentDay').iloc[-1]
+        d = self._get_demand("currentDay").iloc[-1]
 
-        return {
-            "time": d["Time"],
-            "demand": d["Demand"]
-        }
+        return {"time": d["Time"], "demand": d["Demand"]}
 
     def _get_demand(self, when):
         """Returns demand for currentDay or previousDay"""
@@ -80,31 +78,41 @@ class Ercot(ISOBase):
 
         Updates every 5 minutes
         """
-        url = 'https://www.ercot.com/api/1/services/read/dashboards/todays-outlook.json'
+        url = "https://www.ercot.com/api/1/services/read/dashboards/todays-outlook.json"
         r = self._get_json(url)
 
         date = pd.to_datetime(r["lastUpdated"][:10], format="%Y-%m-%d")
 
         # ignore last row since that corresponds to midnight following day
-        data = pd.DataFrame(r['data'][:-1])
+        data = pd.DataFrame(r["data"][:-1])
 
-        data["Time"] = data.apply(lambda x, date=date: pd.Timestamp(
-            year=date.year, month=date.month, day=date.day, hour=int(x["hourEnding"]), minute=int(x["interval"])), axis=1)
+        data["Time"] = pd.to_datetime(
+            date.strftime("%Y-%m-%d")
+            + " "
+            + data["hourEnding"].astype(str).str.zfill(2)
+            + ":"
+            + data["interval"].astype(str).str.zfill(2),
+        ).dt.tz_localize(self.default_timezone)
 
         data = data[data["forecast"] == 0]  # only keep non forecast rows
 
-        data = data[["Time", "capacity"]].rename(
-            columns={"capacity": "Supply"})
+        data = data[["Time", "capacity"]].rename(columns={"capacity": "Supply"})
 
         return data
 
     def get_prices(self):
         pass
+
+    # https://www.ercot.com/mktinfo
     # https://www.ercot.com/api/1/services/read/dashboards/systemWidePrices.json
+    # https://www.ercot.com/mp/data-products/markets/real-time-market?id=NP6-788-CD
 
     def _handle_data(self, df, columns):
-        df["Time"] = pd.to_datetime(df["epoch"], unit="ms").dt.tz_localize(
-            "UTC").dt.tz_convert(self.default_timezone)
+        df["Time"] = (
+            pd.to_datetime(df["epoch"], unit="ms")
+            .dt.tz_localize("UTC")
+            .dt.tz_convert(self.default_timezone)
+        )
 
         cols_to_keep = ["Time"] + list(columns.keys())
         return df[cols_to_keep].rename(columns=columns)
