@@ -7,22 +7,47 @@ import requests
 
 import isodata
 from isodata import utils
-from isodata.base import FuelMix, ISOBase, Markets
+from isodata.base import FuelMix, GridStatus, ISOBase, Markets
 
 
 class NYISO(ISOBase):
     name = "New York ISO"
     iso_id = "nyiso"
     default_timezone = "US/Eastern"
+    markets = [Markets.REAL_TIME_5_MIN, Markets.DAY_AHEAD_5_MIN]
 
-    # Markets
-    REAL_TIME_5_MIN = Markets.REAL_TIME_5_MIN
-    DAY_AHEAD_5_MIN = Markets.DAY_AHEAD_5_MIN
+    def get_latest_status(self):
+        latest = self._latest_from_today(self.get_status_today)
 
-    # def get_latest_status(self):
-    #     # https://www.nyiso.com/en/system-conditions
-    #      http://mis.nyiso.com/public/P-35list.htm
-    #     pass
+        status = GridStatus(
+            time=latest["time"],
+            status=latest["status"],
+            reserves=None,
+            iso=self.name,
+            notes=None,
+        )
+        return status
+
+    def get_status_today(self):
+        """Get status event for today"""
+        d = self._today_from_historical(self.get_historical_status)
+        return d
+
+    def get_status_yesterday(self):
+        """Get status event for yesterday"""
+        return self._yesterday_from_historical(self.get_historical_status)
+
+    def get_historical_status(self, date):
+        """Get status event for a date"""
+        status_df = _download_nyiso_archive(date, "RealTimeEvents")
+
+        status_df = status_df.rename(columns={"Timestamp": "Time", "Message": "Status"})
+
+        status_df["Time"] = pd.to_datetime(status_df["Time"]).dt.tz_localize(
+            self.default_timezone,
+        )
+
+        return status_df
 
     def get_latest_fuel_mix(self):
         # note: this is simlar datastructure to pjm
@@ -111,35 +136,44 @@ class NYISO(ISOBase):
         """Returns supply at a previous date in 5 minute intervals"""
         return self._supply_from_fuel_mix(date)
 
-    def get_latest_lmp(self, market: str, nodes: list):
-        return self._latest_lmp_from_today(market, nodes, node_column="Zone")
+    def get_latest_lmp(self, market: str, locations: list = None):
+        return self._latest_lmp_from_today(market, locations)
 
-    def get_lmp_today(self, market: str, nodes: list):
+    def get_lmp_today(self, market: str, locations: list = None):
         "Get lmp for today in 5 minute intervals"
-        return self._today_from_historical(self.get_historical_lmp, market, nodes)
+        return self._today_from_historical(self.get_historical_lmp, market, locations)
 
-    def get_lmp_yesterday(self, market: str, nodes: list):
+    def get_lmp_yesterday(self, market: str, locations: list = None):
         "Get lmp for yesterday in 5 minute intervals"
-        return self._yesterday_from_historical(self.get_historical_lmp, market, nodes)
+        return self._yesterday_from_historical(
+            self.get_historical_lmp,
+            market,
+            locations,
+        )
 
-    def get_historical_lmp(self, date, market: str, nodes: list):
+    def get_historical_lmp(self, date, market: str, locations: list = None):
         """
         Supported Markets: REAL_TIME_5_MIN, DAY_AHEAD_5_MIN
         """
         # todo support generator and zone
-        if market == self.REAL_TIME_5_MIN:
+        if locations is None:
+            locations = "ALL"
+
+        market = Markets(market)
+        if market == Markets.REAL_TIME_5_MIN:
             marketname = "realtime"
             filename = marketname + "_zone"
-        if market == self.DAY_AHEAD_5_MIN:
+        elif market == Markets.DAY_AHEAD_5_MIN:
             marketname = "damlbmp"
             filename = marketname + "_zone"
+        else:
+            raise RuntimeError("LMP Market is not supported")
 
         df = _download_nyiso_archive(date, market_name=marketname, filename=filename)
 
-        # todo handle node
         columns = {
             "Time Stamp": "Time",
-            "Name": "Zone",
+            "Name": "Location",
             "LBMP ($/MWHr)": "LMP",
             "Marginal Cost Losses ($/MWHr)": "Loss",
             "Marginal Cost Congestion ($/MWHr)": "Congestion",
@@ -148,22 +182,29 @@ class NYISO(ISOBase):
         df = df.rename(columns=columns)
 
         df["Energy"] = df["LMP"] - (df["Loss"] - df["Congestion"])
-        df["Market"] = market
+        df["Market"] = market.value
+        df["Location Type"] = "Zone"
 
-        df = df[["Time", "Market", "Zone", "LMP", "Energy", "Congestion", "Loss"]]
+        df = df[
+            [
+                "Time",
+                "Market",
+                "Location",
+                "Location Type",
+                "LMP",
+                "Energy",
+                "Congestion",
+                "Loss",
+            ]
+        ]
 
         df["Time"] = pd.to_datetime(df["Time"]).dt.tz_localize(self.default_timezone)
 
-        data = utils.filter_lmp_nodes(df, nodes, node_column="Zone")
+        data = utils.filter_lmp_locations(df, locations)
 
         return df
 
 
-# def get_day_ahead_prices(self,)
-
-# https://www.nyiso.com/energy-market-operational-data
-
-
 def _download_nyiso_archive(date, market_name, filename=None):
 
     if filename is None:
