@@ -9,6 +9,23 @@ from isodata.base import FuelMix, GridStatus, ISOBase
 all_isos = [MISO(), CAISO(), PJM(), Ercot(), SPP(), NYISO(), ISONE()]
 
 
+def check_lmp_columns(df):
+    assert set(df.columns) == set(
+        [
+            "Time",
+            "Market",
+            "Location",
+            "Location Type",
+            "LMP",
+            "Energy",
+            "Congestion",
+            "Loss",
+        ],
+    )
+
+    # todo check if market is valid enum
+
+
 def test_make_lmp_availability_df():
     isodata.utils.make_lmp_availability_table()
 
@@ -48,12 +65,19 @@ def test_get_iso_invalid():
         isodata.get_iso("ISO DOESNT EXIST")
 
 
-@pytest.mark.parametrize("iso", [CAISO(), Ercot()])
+@pytest.mark.parametrize("iso", [NYISO(), ISONE(), CAISO(), Ercot()])
 def test_get_latest_status(iso):
     status = iso.get_latest_status()
     assert isinstance(status, GridStatus)
 
 
+@pytest.mark.parametrize("iso", [NYISO()])
+def test_get_historical_status(iso):
+    date = "20220609"
+    status = iso.get_historical_status(date)
+    assert isinstance(status, pd.DataFrame)
+
+
 @pytest.mark.parametrize("iso", [ISONE(), NYISO(), PJM(), CAISO()])
 def test_get_historical_fuel_mix(iso):
     # date string works
@@ -171,24 +195,21 @@ def test_get_historical_demand(iso):
         {
             CAISO(): {
                 "markets": [
-                    CAISO.REAL_TIME_HOURLY,
-                    CAISO.DAY_AHEAD_HOURLY,
-                    CAISO.REAL_TIME_15_MIN,
+                    Markets.REAL_TIME_HOURLY,
+                    Markets.DAY_AHEAD_HOURLY,
+                    Markets.REAL_TIME_15_MIN,
                 ],
-                "nodes": None,
             },
         },
         {
             ISONE(): {
-                # , ISONE.REAL_TIME_5_MIN
-                "markets": [ISONE.DAY_AHEAD_HOURLY, ISONE.REAL_TIME_HOURLY],
-                "nodes": "ALL",
+                # , Markets.REAL_TIME_5_MIN
+                "markets": [Markets.DAY_AHEAD_HOURLY, Markets.REAL_TIME_HOURLY],
             },
         },
         {
             NYISO(): {
-                "markets": [NYISO.DAY_AHEAD_5_MIN, NYISO.REAL_TIME_5_MIN],
-                "nodes": "ALL",
+                "markets": [Markets.DAY_AHEAD_5_MIN, Markets.REAL_TIME_5_MIN],
             },
         },
     ],
@@ -196,15 +217,16 @@ def test_get_historical_demand(iso):
 def test_get_historical_lmp(test):
     iso = list(test)[0]
     markets = test[iso]["markets"]
-    nodes = test[iso]["nodes"]
 
     date_str = "20220722"
     for m in markets:
         print(iso.iso_id, m)
-        hist = iso.get_historical_lmp(date_str, m, nodes=nodes)
+        hist = iso.get_historical_lmp(date_str, m)
         assert isinstance(hist, pd.DataFrame)
-        yesterday = iso.get_lmp_yesterday(m, nodes=nodes)
+        check_lmp_columns(hist)
+        yesterday = iso.get_lmp_yesterday(m)
         assert isinstance(yesterday, pd.DataFrame)
+        check_lmp_columns(yesterday)
 
 
 @pytest.mark.parametrize(
@@ -213,29 +235,25 @@ def test_get_historical_lmp(test):
         {
             CAISO(): {
                 "markets": [
-                    CAISO.REAL_TIME_HOURLY,
-                    CAISO.DAY_AHEAD_HOURLY,
-                    CAISO.REAL_TIME_15_MIN,
+                    Markets.REAL_TIME_HOURLY,
+                    Markets.DAY_AHEAD_HOURLY,
+                    Markets.REAL_TIME_15_MIN,
                 ],
-                "nodes": None,
             },
         },
         {
             ISONE(): {
-                "markets": [ISONE.REAL_TIME_5_MIN, ISONE.REAL_TIME_HOURLY],
-                "nodes": "ALL",
+                "markets": [Markets.REAL_TIME_5_MIN, Markets.REAL_TIME_HOURLY],
             },
         },
         {
             MISO(): {
-                "markets": [MISO.REAL_TIME_5_MIN, MISO.DAY_AHEAD_HOURLY],
-                "nodes": "ALL",
+                "markets": [Markets.REAL_TIME_5_MIN, Markets.DAY_AHEAD_HOURLY],
             },
         },
         {
             NYISO(): {
-                "markets": [NYISO.DAY_AHEAD_5_MIN, NYISO.REAL_TIME_5_MIN],
-                "nodes": "ALL",
+                "markets": [Markets.DAY_AHEAD_5_MIN, Markets.REAL_TIME_5_MIN],
             },
         },
     ],
@@ -243,13 +261,14 @@ def test_get_historical_lmp(test):
 def test_get_latest_lmp(test):
     iso = list(test)[0]
     markets = test[iso]["markets"]
-    nodes = test[iso]["nodes"]
+    locations = test[iso]
 
     date_str = "20220722"
     for m in markets:
         print(iso.iso_id, m)
-        latest = iso.get_latest_lmp(m, nodes=nodes)
+        latest = iso.get_latest_lmp(m)
         assert isinstance(latest, pd.DataFrame)
+        check_lmp_columns(latest)
 
 
 @pytest.mark.parametrize(
@@ -258,23 +277,20 @@ def test_get_latest_lmp(test):
         {
             CAISO(): {
                 "markets": [
-                    CAISO.REAL_TIME_HOURLY,
-                    CAISO.REAL_TIME_15_MIN,
-                    CAISO.DAY_AHEAD_HOURLY,
+                    Markets.REAL_TIME_HOURLY,
+                    Markets.REAL_TIME_15_MIN,
+                    Markets.DAY_AHEAD_HOURLY,
                 ],
-                "nodes": None,
             },
         },
         {
             ISONE(): {
-                "markets": [ISONE.DAY_AHEAD_HOURLY, ISONE.REAL_TIME_5_MIN],
-                "nodes": "ALL",
+                "markets": [Markets.DAY_AHEAD_HOURLY, Markets.REAL_TIME_5_MIN],
             },
         },
         {
             NYISO(): {
-                "markets": [NYISO.DAY_AHEAD_5_MIN, NYISO.REAL_TIME_5_MIN],
-                "nodes": "ALL",
+                "markets": [Markets.DAY_AHEAD_5_MIN, Markets.REAL_TIME_5_MIN],
             },
         },
     ],
@@ -282,8 +298,8 @@ def test_get_latest_lmp(test):
 def test_get_lmp_today(test):
     iso = list(test)[0]
     markets = test[iso]["markets"]
-    nodes = test[iso]["nodes"]
 
     for m in markets:
-        today = iso.get_lmp_today(m, nodes=nodes)
+        today = iso.get_lmp_today(m)
         assert isinstance(today, pd.DataFrame)
+        check_lmp_columns(today)
